@@ -16,7 +16,7 @@ StreamFinder - Fetch actual raw streamable URLs from various radio-station, vide
 
 =head1 AUTHOR
 
-This module is Copyright (C) 2017-2021 by
+This module is Copyright (C) 2017-2022 by
 
 Jim Turner, C<< <turnerjw784 at yahoo.com> >>
 		
@@ -129,7 +129,8 @@ site URL as the argument.  You can then edit it to tailor it to your needs.
 
 The currently-supported websites are:  podcasts.apple.com (L<StreamFinder::Apple>), 
 bitchute.com (L<StreamFinder::Bitchute>), blogger.com (L<StreamFinder::Blogger>), 
-brighteon.com (L<StreamFinder::Brighteon>), castbox.fm (L<StreamFinder::Castbox>), 
+brandnewtube.com (L<StreamFinder::BrandNewTube>), brighteon.com 
+(L<StreamFinder::Brighteon>), castbox.fm (L<StreamFinder::Castbox>), 
 podcasts.google.com (L<StreamFinder::Google>), 
 iheartradio.com (L<StreamFinder::IHeartRadio>), 
 odysee.com (L<StreamFinder::Odysee>), podbean.com (L<StreamFinder::Podbean>), 
@@ -330,10 +331,10 @@ the "icon image" data, if any, will be returned.
 =item $station->B<getType>()
 
 Returns the station / podcast / video's type (I<submodule-name>).  
-(one of:  "Anystream", "Apple", "BitChute", "Blogger", "Brighteon", 
-"Castbox", "Google", "IHeartRadio", "Odysee", "Podbean", "RadioNet", 
-"Rumble", "SermonAudio", "Spreaker", "Tunein", "Youtube" or "Vimeo" - 
-depending on the sight that matched the URL).
+(one of:  "Anystream", "Apple", "BitChute", "Blogger", "BrandNewTube", 
+"Brighteon", "Castbox", "Google", "IHeartRadio", "Odysee", "Podbean", 
+"RadioNet", "Rumble", "SermonAudio", "Spreaker", "Tunein", "Youtube" 
+or "Vimeo" - depending on the sight that matched the URL).
 
 =back
 
@@ -437,7 +438,7 @@ L<http://search.cpan.org/dist/StreamFinder/>
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright 2017-2021 Jim Turner.
+Copyright 2017-2022 Jim Turner.
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of the the Artistic License (2.0). You may obtain a
@@ -485,15 +486,15 @@ use strict;
 use warnings;
 use vars qw(@ISA @EXPORT $VERSION);
 
-our $VERSION = '1.82';
+our $VERSION = '1.83';
 our $DEBUG = 0;
 
 require Exporter;
 
 @ISA = qw(Exporter);
 @EXPORT = qw();
-my @supported_mods = (qw(Anystream Apple Bitchute Blogger Brighteon Castbox Google IHeartRadio
-		Odysee Podbean RadioNet Rumble SermonAudio Spreaker Tunein Vimeo Youtube));
+my @supported_mods = (qw(Anystream Apple Bitchute Blogger BrandNewTube Brighteon Castbox Google
+		IHeartRadio Odysee Podbean RadioNet Rumble SermonAudio Spreaker Tunein Vimeo Youtube));
 
 my %haveit;
 
@@ -557,6 +558,8 @@ sub new
 		return new StreamFinder::Odysee($url, @args);
 	} elsif ($haveit{'Podbean'} && $url =~ m#\bpodbean\.com\/#) {
 		return new StreamFinder::Podbean($url, @args);
+	} elsif ($haveit{'BrandNewTube'} && $url =~ m#\bbrandnewtube\.#) {
+		return new StreamFinder::BrandNewTube($url, @args);
 	} elsif ($haveit{'Youtube'}) {  #DEFAULT TO youtube-dl SINCE SO MANY URLS ARE HANDLED THERE NOW.
 		my $yt = new StreamFinder::Youtube($url, @args);
 		return $yt  if (defined($yt) && $yt && $yt->count() > 0);
